// Load in the required modules
const Materials = require('Materials');
const Scene = require('Scene');
const Time = require('Time');
const TouchGestures = require('TouchGestures');

// Access the objects and materials in the scene
const leftPlane = Scene.root.find('leftPlane');
const rightPlane = Scene.root.find('rightPlane');
const redMaterial = Materials.get('redMaterial');
const blueMaterial = Materials.get('blueMaterial');

// Create a time variable used in the timers below
const timeInMilliseconds = 500;
// Create a boolean used for switching the left plane's material below
var isLeftPlaneRed = true;

/* Use the setInterval method to create a function that is called every interval
as defined by the timeInMilliseconds variable above */
const intervalTimer = Time.setInterval(function () {
  /* Swap the boolean so we swap the material applied to the left plane everytime
  this function is called (half a second) */
  isLeftPlaneRed = !isLeftPlaneRed;
  if (isLeftPlaneRed) {
    leftPlane.material = redMaterial;
  }
  else {
    leftPlane.material = blueMaterial;
  }
}, timeInMilliseconds);

/* Use the setTimeout method to create a function that is called after the interval
as defined by the timeInMilliseconds variable above multiplied by 10 (5 seconds) */
const timeoutTimer = Time.setTimeout(function () {
  // Change the material of the right plane from blue to red
  rightPlane.material = redMaterial;
}, timeInMilliseconds*10);

/* The code below relies on the 'Tap Gesture' funtionality being added in the project
properties */

/* Cancel the interval timer when you tap on the left plane, this will stop the
color switching */
TouchGestures.onTap(leftPlane).subscribe(function () {
  Time.clearInterval(intervalTimer);
});

/* Cancel the timeout timer when you tap on the right plane, if done before 5
seconds has elapsed this will stop it from changing to red */
TouchGestures.onTap(rightPlane).subscribe(function () {
  Time.clearInterval(timeoutTimer);
});
